@@ -1,8 +1,9 @@
+import contextlib
 import json
 import logging
 import os
+from typing import Any, Dict
 import zipfile
-import contextlib
 
 from ncbi.datasets.reports.report_reader import DatasetsReportReader
 import ncbi.datasets.v1alpha1.reports.assembly_pb2 as assembly_report_pb2
@@ -11,7 +12,7 @@ import ncbi.datasets.v1alpha1.reports.gene_pb2 as gene_report_pb2
 logger = logging.getLogger()
 
 
-def GetDatasetFromFile(zip_file_or_directory, dataset_type):  # pylint:disable=invalid-name
+def GetDatasetFromFile(zip_file_or_directory, dataset_type: str):  # pylint:disable=invalid-name
     if dataset_type == 'ASSEMBLY':
         return AssemblyDataset(zip_file_or_directory)
     elif dataset_type == 'GENE':
@@ -21,7 +22,7 @@ def GetDatasetFromFile(zip_file_or_directory, dataset_type):  # pylint:disable=i
     raise ValueError(dataset_type)
 
 
-def _get_files_of_type(elt, file_type, results):
+def _get_files_of_type(elt: Dict[str, Any], file_type, results):
     if isinstance(elt, dict):
         for k, v in elt.items():
             if k == 'files' and isinstance(v, list):
@@ -33,7 +34,7 @@ def _get_files_of_type(elt, file_type, results):
             _get_files_of_type(v, file_type, results)
 
 
-def _get_file_types(elt, results):
+def _get_file_types(elt: Dict[str, Any], results):
     if isinstance(elt, dict):
         for k, v in elt.items():
             if k == 'files' and isinstance(v, list):
@@ -58,7 +59,6 @@ class Dataset():
         # Top-level directory for files. If data is stored in a zip file this is the data
         # directory in the zip file (ncbi_dataset/data), otherwise it's the full data directory path.
         self.dataset_dir = None
-        self._dataset_catalog = {}
 
         if os.path.isdir(zipfile_or_directory):
             self.dataset_dir = os.path.join(zipfile_or_directory, 'data')
@@ -80,17 +80,15 @@ class Dataset():
         return self.dataset_dir
 
     # return json catalog from zip file
-    def get_catalog(self):
-        if self._dataset_catalog:
-            return self._dataset_catalog
-
+    def get_catalog(self) -> Dict[str, Any]:
+        dataset_catalog: Dict[str, Any]
         catalog_file = self.get_file_content('dataset_catalog.json')
         if catalog_file:
             try:
-                self._dataset_catalog = json.loads(catalog_file)
+                dataset_catalog = json.loads(catalog_file)
             except json.JSONDecodeError as e:
                 logger.error('Error decoding dataset_catalog file to json: %s', e)
-        return self._dataset_catalog
+        return dataset_catalog
 
     # return names of all files of type 'file_type', eg. 'PROTEIN_FASTA'
     def get_file_names_by_type(self, file_type):
